==> blink-components-0.4.0.tgz: package/components/Carousel/index.js <==
// @flow

import React from 'react'
import { themr } from 'react-css-themr'
import cn from 'classnames'
import { defaultProps } from 'recompose'
import Nuka from 'nuka-carousel'
import Icon from 'components/Icon'

const PreviousButton = ({
  previousSlide,
  className,
}: {
  previousSlide: Function,
  className?: string,
}) => (
  <Icon
    name="fa-angle-left"
    className={className}
    onClick={() => previousSlide()}
  />
)

PreviousButton.defaultProps = {
  className: null,
}

const NextButton = ({
  nextSlide,
  className,
}: {
  nextSlide: Function,
  className?: string,
}) => (
  <Icon
    name="fa-angle-right"
    className={className}
    onClick={() => nextSlide()}
  />
)

NextButton.defaultProps = {
  className: undefined,
}

export const defaultStyles = {
  button: 'w1 h1 pointer bg-black-10 br-100 pa1',
}

const Carousel = ({
  slidesToShow = 1,
  className,
  theme,
  items,
  renderItem,
}: {
  slidesToShow?: number,
  items: Array<any>,
  renderItem: Function,
  theme: { [key: string]: string },
  className?: string,
}) => (
  <div className={cn(theme.root, className)}>
    <Nuka
      slidesToShow={slidesToShow}
      decorators={[
        {
          component: () => null,
          position: 'BottomCenter',
          style: {
            padding: 20,
          },
        },
        {
          component: defaultProps({ className: theme.button })(PreviousButton),
          position: 'CenterLeft',
          style: {
            padding: 20,
          },
        },
        {
          component: defaultProps({ className: theme.button })(NextButton),
          position: 'CenterRight',
          style: {
            padding: 20,
          },
        },
      ]}
    >
      {items.map(x => renderItem(x))}
    </Nuka>
  </div>
)

Carousel.defaultProps = {
  slidesToShow: 1,
  className: undefined,
}

export default themr('Carousel', {}, { composeTheme: 'softly' })(Carousel)

==> blink-components-0.4.5.tgz: package/components/Carousel/index.js <==
// @flow

import React from 'react'
import { themr } from 'react-css-themr'
import cn from 'classnames'
import { defaultProps } from 'recompose'
import Nuka from 'nuka-carousel'
import Icon from 'components/Icon'

const PreviousButton = ({
  previousSlide,
  className,
}: {
  previousSlide: Function,
  className?: string,
}) => (
  <Icon
    name="fa-angle-left"
    className={className}
    onClick={() => previousSlide()}
  />
)

PreviousButton.defaultProps = {
  className: null,
}

const NextButton = ({
  nextSlide,
  className,
}: {
  nextSlide: Function,
  className?: string,
}) => (
  <Icon
    name="fa-angle-right"
    className={className}
    onClick={() => nextSlide()}
  />
)

NextButton.defaultProps = {
  className: undefined,
}

export const defaultStyles = {
  button: 'w1 h1 pointer bg-black-10 br-100 pa1',
}

const Carousel = ({
  slidesToShow = 1,
  className,
  theme,
  items,
  renderItem,
}: {
  slidesToShow?: number,
  items: Array<any>,
  renderItem: Function,
  theme: { [key: string]: string },
  className?: string,
}) => (
  <div data-component="Carousel" className={cn(theme.root, className)}>
    <Nuka
      slidesToShow={slidesToShow}
      decorators={[
        {
          component: () => null,
          position: 'BottomCenter',
          style: {
            padding: 20,
          },
        },
        {
          component: defaultProps({ className: theme.button })(PreviousButton),
          position: 'CenterLeft',
          style: {
            padding: 20,
          },
        },
        {
          component: defaultProps({ className: theme.button })(NextButton),
          position: 'CenterRight',
          style: {
            padding: 20,
          },
        },
      ]}
    >
      {items.map(x => renderItem(x))}
    </Nuka>
  </div>
)

Carousel.defaultProps = {
  slidesToShow: 1,
  className: undefined,
}

export default themr('Carousel', {}, { composeTheme: 'softly' })(Carousel)
